@@ -1,6 +1,6 @@
 package BankAccount::Validator::UK;
 
-$BankAccount::Validator::UK::VERSION   = '0.42';
+$BankAccount::Validator::UK::VERSION   = '0.43';
 $BankAccount::Validator::UK::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,7 +9,7 @@ BankAccount::Validator::UK - Interface to validate UK bank account.
 
 =head1 VERSION
 
-Version 0.42
+Version 0.43
 
 =cut
 
@@ -36,7 +36,7 @@ has sort_code  => (is => 'ro', default => sub { BankAccount::Validator::UK::Rule
 The module uses the algorithm provided by VOCALINK to validate the bank sort code
 and account number.  It is  done by modulus  checking  method as specified in the
 document which is available on their website L<VOCALINK|https://www.vocalink.com/customer-support/modulus-checking>
-It currently supports the document L<v5.10|https://www.vocalink.com/media/3035/validating-account-numbers-v510.pdf> dated 31st July 2018.
+It currently supports the document L<v5.20|https://www.vocalink.com/media/3038/validating-account-numbers-v520.pdf> dated 3rd Sep 2018.
 
 Institutions covered by this document are below:
 
@@ -273,9 +273,9 @@ and account number.
 =cut
 
 sub get_trace {
-	my ($self) = @_;
+    my ($self) = @_;
 
-	return $self->{trace} if scalar(@{$self->{trace}});
+    return $self->{trace} if scalar(@{$self->{trace}});
 }
 
 #
